--------------------------------------------------------------------------------
-- d_lmb_wrapper.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

LIBRARY lmb_v10_v1_00_a;
USE lmb_v10_v1_00_a.ALL;

ENTITY d_lmb_wrapper IS
PORT (
	-- instance d_lmb
	LMB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	LMB_Rst : OUT STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	M_ReadStrobe : IN STD_LOGIC;
	M_WriteStrobe : IN STD_LOGIC;
	M_AddrStrobe : IN STD_LOGIC;
	M_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	M_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	Sl_Ready : IN STD_LOGIC_VECTOR(0 TO 0);
	LMB_ABus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_ReadStrobe : OUT STD_LOGIC;
	LMB_WriteStrobe : OUT STD_LOGIC;
	LMB_AddrStrobe : OUT STD_LOGIC;
	LMB_ReadDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_WriteDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_Ready : OUT STD_LOGIC;
	LMB_BE : OUT STD_LOGIC_VECTOR(0 TO 3));
END d_lmb_wrapper;

ARCHITECTURE IMP OF d_lmb_wrapper IS

--------------------------------------------------------------------------------
COMPONENT lmb_v10 IS
GENERIC (
	C_LMB_NUM_SLAVES : INTEGER := 1;
	C_LMB_AWIDTH : INTEGER := 32;
	C_LMB_DWIDTH : INTEGER := 32;
	C_EXT_RESET_HIGH : INTEGER := 1);
PORT (
	LMB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	LMB_Rst : OUT STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO C_LMB_AWIDTH-1);
	M_ReadStrobe : IN STD_LOGIC;
	M_WriteStrobe : IN STD_LOGIC;
	M_AddrStrobe : IN STD_LOGIC;
	M_DBus : IN STD_LOGIC_VECTOR(0 TO C_LMB_DWIDTH-1);
	M_BE : IN STD_LOGIC_VECTOR(0 TO (C_LMB_DWIDTH+7)/8-1);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO (C_LMB_DWIDTH*C_LMB_NUM_SLAVES)-1);
	Sl_Ready : IN STD_LOGIC_VECTOR(0 TO C_LMB_NUM_SLAVES-1);
	LMB_ABus : OUT STD_LOGIC_VECTOR(0 TO C_LMB_AWIDTH-1);
	LMB_ReadStrobe : OUT STD_LOGIC;
	LMB_WriteStrobe : OUT STD_LOGIC;
	LMB_AddrStrobe : OUT STD_LOGIC;
	LMB_ReadDBus : OUT STD_LOGIC_VECTOR(0 TO C_LMB_DWIDTH-1);
	LMB_WriteDBus : OUT STD_LOGIC_VECTOR(0 TO C_LMB_DWIDTH-1);
	LMB_Ready : OUT STD_LOGIC;
	LMB_BE : OUT STD_LOGIC_VECTOR(0 TO (C_LMB_DWIDTH+7)/8-1));
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
--------------------------------------------------------------------------------
-- Lower-level assignments

--------------------------------------------------------------------------------
lmb_v10_0_i : lmb_v10
GENERIC MAP (
	C_LMB_NUM_SLAVES => 1,
	C_LMB_AWIDTH => 32,
	C_LMB_DWIDTH => 32,
	C_EXT_RESET_HIGH => 1)
PORT MAP (
	LMB_Clk => LMB_Clk,
	SYS_Rst => SYS_Rst,
	LMB_Rst => LMB_Rst,
	M_ABus => M_ABus,
	M_ReadStrobe => M_ReadStrobe,
	M_WriteStrobe => M_WriteStrobe,
	M_AddrStrobe => M_AddrStrobe,
	M_DBus => M_DBus,
	M_BE => M_BE,
	Sl_DBus => Sl_DBus,
	Sl_Ready => Sl_Ready,
	LMB_ABus => LMB_ABus,
	LMB_ReadStrobe => LMB_ReadStrobe,
	LMB_WriteStrobe => LMB_WriteStrobe,
	LMB_AddrStrobe => LMB_AddrStrobe,
	LMB_ReadDBus => LMB_ReadDBus,
	LMB_WriteDBus => LMB_WriteDBus,
	LMB_Ready => LMB_Ready,
	LMB_BE => LMB_BE);

END ARCHITECTURE IMP;
